import setuptools


long_description = """
# fuzzy-c-means
Fuzzy c-means Clustering

## Description
This implementation is based on the paper
**FCM: The fuzzy c-means clustering algorithm**  by: *James C.Bezdek, Robert Ehrlich, and  William Full*

## To run the tests
`sh tests/run_tests.sh`

## Install via pip
```pip install fuzzycmeans```

"""


setuptools.setup(
    name="fuzzycmeans",
    version="1.0.3",
    author="Ahmad Alobaid",
    author_email="aalobaid@fi.upm.es",
    description="Fuzzy c-means according to the research paper by James C. Bezdek et. al",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/oeg-upm/fuzzy-c-means",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development :: Libraries",
    ),
    install_requires=[
              'numpy', 'six', 'bokeh'
    ],

)



import pytest
import numpy as np
from fuzzycmeans import FCM


def single_known_cluster():
    X = np.array([[1, 1], [1, 2], [2, 2]])
    fcm = FCM(n_clusters=3, max_iter=1)
    fcm.fit(X, [0, 0, 0])


def fit_from_centroids():
    data_test = [178.75, 5.97390157]
    data_height = [170., 186., 182., 177.]
    data_size = [40, 42, 45, 47, 50]
    data_injuries = [3, 4, 1, 0]
    centers = [[175., 4.08],
               [44.8, 3.54],
               [2., 1.58]]
    fcm = FCM(n_clusters=3, max_iter=1)
    fcm.cluster_centers_ = np.array(centers)
    fcm.fit(fcm.cluster_centers_, [0, 1, 2])
    membership_height = fcm.predict(np.array([data_test]))
    membership_height = fcm.predict(np.array([[np.average(data_height), np.std(data_height)]]))
    membership_size = fcm.predict(np.array([[np.average(data_size), np.std(data_size)]]))
    membership_injuries = fcm.predict(np.array([[np.average(data_injuries), np.std(data_injuries)]]))